=============================
Text with moving letters
=============================

I think this example illustrates well the interest of script-based editing (imagine doing that by hand).

.. raw:: html

        <center>
        <object><param name="movie"
        value="http://www.youtube.com/v/jj5qrHl5ZS0&hl=en_US&fs=1&rel=0">
        </param><param name="allowFullScreen" value="true"></param><param
        name="allowscriptaccess" value="always"></param><embed
        src="http://www.youtube.com/v/jj5qrHl5ZS0&hl=en_US&fs=1&rel=0"
        type="application/x-shockwave-flash" allowscriptaccess="always"
        allowfullscreen="true" width="550" height="450"></embed></object>
        </center>


Here is the code:

.. literalinclude:: ../../examples/moving_letters.py
